@@ -225,7 +225,20 @@ format.version_sentinel <-
 .get_R_version <- function()
     getRversion()
 
+.version_string <-
+    function(bioc_version = version())
+{
+    sprintf(
+        "Bioconductor version %s (BiocManager %s), %s",
+        bioc_version, packageVersion("BiocManager"),
+        sub(" version", "", R.version.string)
+    )
+}
 
+## .version_validity() returns TRUE if the version is valid for this
+## version of R, or a text string (created with sprintf()) explaining why
+## the version is invalid. It does NOT call message / warning / etc
+## directly.
 .version_validity <-
     function(version, map = .version_map(), r_version = .get_R_version())
 {
@@ -256,11 +269,11 @@ format.version_sentinel <-
         one_up <- required
         one_up[, 2] <- as.integer(required[, 2]) + 1L
         if (r_version == one_up && "future" %in% rec$BiocStatus)
-            .message(
-                "Bioconductor version '%s' requires R version '%s'; %s; %s",
-                version, head(required, 1), "R version is too new",
-                .VERSION_HELP
-            )
+            return(sprintf(
+                "Bioconductor does not yet build and check packages for R
+                 version %s; %s",
+                r_version, .VERSION_HELP
+            ))
         else {
             rec_fun <- ifelse("devel" %in% rec$BiocStatus, head, tail)
             rec_msg <- sprintf(
@@ -268,7 +281,7 @@ format.version_sentinel <-
                 rec_fun(rec$Bioc, 1), r_version
             )
 
-            return(.msg(
+            return(sprintf(
                 "Bioconductor version '%s' requires R version '%s'; %s; %s",
                 version, head(required, 1), rec_msg, .VERSION_HELP
             ))
@@ -289,8 +302,9 @@ format.version_sentinel <-
     status <- map$BiocStatus[map$Bioc == version & map$R == r_version]
     if (identical(status, "future"))
         return(sprintf(
-            "Bioconductor does not yet formally support R version '%s'",
-            r_version
+            "Bioconductor does not yet build and check packages for R version
+             %s; %s",
+            r_version, .VERSION_HELP
         ))
 
     TRUE
