@@ -129,13 +129,9 @@ test_that(".version_validity(...) works", {
         "BiocManager::install"
     )
 
-    expect_true(
-        .version_validity("4.1", .ver_map, .get_R_ver("4.5.0"))
-    )
-
-    expect_message(
+    expect_match(
         .version_validity("4.1", .ver_map, .get_R_ver("4.5.0")),
-        "R version is too new"
+        "does not yet build"
     )
 })
 
